.. OrcaSong documentation master file
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |vspace| raw:: latex

   \vspace{1cm}

.. image:: _static/orcasong_wide_transparent.png
   :height: 142px

|vspace|

.. include:: ../Readme.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   orcasong
   tools
   CONTRIBUTING
   Source (Git) <https://git.km3net.de/ml/OrcaSong.git>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
